@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 # Preloaded methods go here.
 
@@ -553,7 +553,7 @@ __DATA__
 667-675	?? Unknown
 676-679 ?? New area allocated, but not yet issued
 680	?? Unknown
-681-690 ?? New area allocated, but not yet issued
+681-690 ?? Unknown
 691-699 ?? New area allocated, but not yet issued
 700-728  RB   Railroad Board (discontinued July 1, 1963)
 750-751 ?? New area allocated, but not yet issued
@@ -564,27 +564,27 @@ __DATA__
 900-999 ?? Taxpayer Identification Number
 ## high groups
 # This is scraped directly from
-# http://www.ssa.gov/employer/highgroup.txt
-001,06
+# http://www.socialsecurity.gov/employer/ssns/highgroup.txt
+001,08
 002,06
-003,04
-004,08
-005,08
+003,06
+004,11
+005,11
 006,08
-007,06
-008,90
-009,90
-010,90
-011,90
-012,90
-013,90
-014,90
-015,90
-016,90
-017,90
-018,90
-019,90
-020,90
+007,08
+008,92
+009,92
+010,92
+011,92
+012,92
+013,92
+014,92
+015,92
+016,92
+017,92
+018,92
+019,92
+020,92
 021,90
 022,90
 023,90
@@ -596,64 +596,64 @@ __DATA__
 029,90
 030,90
 031,90
-032,88
-033,88
-034,88
-035,72
+032,90
+033,90
+034,90
+035,74
 036,72
 037,72
 038,72
-039,70
-040,11
-041,11
-042,11
-043,11
-044,11
-045,11
-046,11
+039,72
+040,13
+041,13
+042,13
+043,13
+044,13
+045,13
+046,13
 047,11
 048,11
 049,11
-050,96
-051,96
-052,96
-053,96
-054,96
-055,96
-056,96
-057,96
-058,96
-059,96
-060,96
-061,96
-062,96
-063,96
-064,96
-065,96
-066,96
-067,96
-068,96
-069,96
-070,96
-071,96
-072,96
-073,96
-074,96
-075,96
-076,96
-077,96
-078,96
-079,96
-080,96
-081,96
-082,96
-083,96
-084,96
-085,96
-086,96
-087,96
-088,96
-089,96
+050,98
+051,98
+052,98
+053,98
+054,98
+055,98
+056,98
+057,98
+058,98
+059,98
+060,98
+061,98
+062,98
+063,98
+064,98
+065,98
+066,98
+067,98
+068,98
+069,98
+070,98
+071,98
+072,98
+073,98
+074,98
+075,98
+076,98
+077,98
+078,98
+079,98
+080,98
+081,98
+082,98
+083,98
+084,98
+085,98
+086,98
+087,98
+088,98
+089,98
 090,96
 091,96
 092,96
@@ -689,40 +689,40 @@ __DATA__
 122,96
 123,96
 124,96
-125,94
-126,94
-127,94
-128,94
-129,94
-130,94
-131,94
-132,94
-133,94
-134,94
-135,19
-136,19
-137,19
-138,19
-139,19
-140,19
-141,19
-142,19
-143,19
-144,19
-145,19
-146,19
+125,96
+126,96
+127,96
+128,96
+129,96
+130,96
+131,96
+132,96
+133,96
+134,96
+135,21
+136,21
+137,21
+138,21
+139,21
+140,21
+141,21
+142,21
+143,21
+144,21
+145,21
+146,21
 147,19
 148,19
-149,17
-150,17
-151,17
-152,17
-153,17
-154,17
-155,17
-156,17
-157,17
-158,17
+149,19
+150,19
+151,19
+152,19
+153,19
+154,19
+155,19
+156,19
+157,19
+158,19
 159,84
 160,84
 161,84
@@ -749,44 +749,44 @@ __DATA__
 182,84
 183,84
 184,84
-185,82
-186,82
-187,82
-188,82
-189,82
-190,82
-191,82
-192,82
-193,82
-194,82
-195,82
-196,82
-197,82
-198,82
-199,82
-200,82
-201,82
-202,82
-203,82
-204,82
-205,82
-206,82
-207,82
+185,84
+186,84
+187,84
+188,84
+189,84
+190,84
+191,84
+192,84
+193,84
+194,84
+195,84
+196,84
+197,84
+198,84
+199,84
+200,84
+201,84
+202,84
+203,84
+204,84
+205,84
+206,84
+207,84
 208,82
 209,82
 210,82
 211,82
-212,79
-213,79
-214,79
-215,79
-216,79
-217,79
-218,79
-219,79
-220,79
-221,06
-222,04
+212,83
+213,83
+214,83
+215,83
+216,83
+217,83
+218,83
+219,83
+220,81
+221,08
+222,06
 223,99
 224,99
 225,99
@@ -796,9 +796,9 @@ __DATA__
 229,99
 230,99
 231,99
-232,53
-233,53
-234,53
+232,55
+233,55
+234,55
 235,53
 236,53
 237,99
@@ -832,15 +832,15 @@ __DATA__
 265,99
 266,99
 267,99
-268,13
-269,13
-270,13
-271,13
-272,13
-273,13
-274,13
-275,13
-276,13
+268,15
+269,15
+270,15
+271,15
+272,15
+273,15
+274,15
+275,15
+276,15
 277,13
 278,13
 279,13
@@ -854,56 +854,56 @@ __DATA__
 287,13
 288,13
 289,13
-290,11
-291,11
-292,11
-293,11
-294,11
-295,11
-296,11
-297,11
-298,11
-299,11
-300,11
-301,11
-302,11
-303,33
+290,13
+291,13
+292,13
+293,13
+294,13
+295,13
+296,13
+297,13
+298,13
+299,13
+300,13
+301,13
+302,13
+303,35
 304,33
 305,33
-306,31
-307,31
-308,31
-309,31
-310,31
-311,31
-312,31
-313,31
-314,31
-315,31
-316,31
-317,31
-318,06
-319,06
-320,06
-321,06
-322,06
-323,06
-324,06
-325,06
-326,06
-327,06
-328,06
-329,06
-330,06
-331,06
-332,06
-333,06
-334,06
-335,06
-336,06
-337,06
-338,06
-339,06
+306,33
+307,33
+308,33
+309,33
+310,33
+311,33
+312,33
+313,33
+314,33
+315,33
+316,33
+317,33
+318,08
+319,08
+320,08
+321,08
+322,08
+323,08
+324,08
+325,08
+326,08
+327,08
+328,08
+329,08
+330,08
+331,08
+332,08
+333,08
+334,08
+335,08
+336,08
+337,08
+338,08
+339,08
 340,06
 341,06
 342,06
@@ -919,59 +919,59 @@ __DATA__
 352,06
 353,06
 354,06
-355,04
-356,04
-357,04
-358,04
-359,04
-360,04
-361,04
-362,35
+355,06
+356,06
+357,06
+358,06
+359,06
+360,06
+361,06
+362,37
 363,35
 364,35
 365,35
 366,35
 367,35
 368,35
-369,33
-370,33
-371,33
-372,33
-373,33
-374,33
-375,33
-376,33
-377,33
-378,33
-379,33
-380,33
-381,33
-382,33
-383,33
-384,33
-385,33
-386,33
-387,29
-388,29
-389,29
-390,29
-391,29
-392,29
+369,35
+370,35
+371,35
+372,35
+373,35
+374,35
+375,35
+376,35
+377,35
+378,35
+379,35
+380,35
+381,35
+382,35
+383,35
+384,35
+385,35
+386,35
+387,31
+388,31
+389,31
+390,31
+391,31
+392,31
 393,29
 394,29
-395,27
-396,27
-397,27
-398,27
-399,27
-400,69
-401,67
-402,67
-403,67
-404,67
-405,67
-406,67
-407,67
+395,29
+396,29
+397,29
+398,29
+399,29
+400,71
+401,69
+402,69
+403,69
+404,69
+405,69
+406,69
+407,69
 408,99
 409,99
 410,99
@@ -980,15 +980,15 @@ __DATA__
 413,99
 414,99
 415,99
-416,63
-417,63
-418,61
-419,61
-420,61
-421,61
-422,61
-423,61
-424,61
+416,65
+417,65
+418,63
+419,63
+420,63
+421,63
+422,63
+423,63
+424,63
 425,99
 426,99
 427,99
@@ -1004,15 +1004,15 @@ __DATA__
 437,99
 438,99
 439,99
-440,23
-441,23
-442,23
-443,23
-444,23
-445,23
-446,23
+440,25
+441,25
+442,25
+443,25
+444,25
+445,25
+446,25
 447,23
-448,21
+448,23
 449,99
 450,99
 451,99
@@ -1032,59 +1032,59 @@ __DATA__
 465,99
 466,99
 467,99
-468,51
-469,51
-470,51
-471,51
-472,51
-473,49
-474,49
-475,49
-476,49
-477,49
-478,37
-479,37
-480,37
-481,37
-482,37
-483,37
+468,53
+469,53
+470,53
+471,53
+472,53
+473,51
+474,51
+475,51
+476,51
+477,51
+478,39
+479,39
+480,39
+481,39
+482,39
+483,39
 484,37
 485,37
-486,25
-487,25
-488,25
-489,25
-490,25
-491,25
-492,25
-493,25
-494,25
+486,27
+487,27
+488,27
+489,27
+490,27
+491,27
+492,27
+493,27
+494,27
 495,25
 496,25
 497,25
 498,25
-499,23
-500,23
-501,33
+499,25
+500,25
+501,35
 502,33
-503,41
-504,39
-505,53
-506,53
-507,51
-508,51
+503,43
+504,41
+505,55
+506,55
+507,53
+508,53
 509,29
-510,27
-511,27
-512,27
-513,27
-514,27
-515,27
-516,45
-517,43
-518,79
-519,77
-520,55
+510,29
+511,29
+512,29
+513,29
+514,29
+515,29
+516,47
+517,45
+518,83
+519,81
+520,57
 521,99
 522,99
 523,99
@@ -1095,20 +1095,20 @@ __DATA__
 528,99
 529,99
 530,99
-531,63
-532,63
-533,63
-534,63
-535,61
-536,61
-537,61
-538,61
-539,61
-540,75
-541,75
-542,73
-543,73
-544,73
+531,65
+532,65
+533,65
+534,65
+535,65
+536,65
+537,65
+538,65
+539,65
+540,77
+541,77
+542,77
+543,77
+544,75
 545,99
 546,99
 547,99
@@ -1138,21 +1138,21 @@ __DATA__
 571,99
 572,99
 573,99
-574,51
+574,55
 575,99
 576,99
-577,45
-578,45
-579,45
-580,37
+577,49
+578,47
+579,47
+580,39
 581,99
 582,99
 583,99
 584,99
 585,99
-586,61
+586,63
 587,99
-588,03
+588,05
 589,99
 590,99
 591,99
@@ -1160,109 +1160,109 @@ __DATA__
 593,99
 594,99
 595,99
-596,84
-597,84
-598,84
-599,84
+596,88
+597,88
+598,86
+599,86
 600,99
 601,99
-602,67
-603,67
-604,67
-605,67
-606,67
-607,67
-608,67
-609,67
-610,65
-611,65
-612,65
-613,65
-614,65
-615,65
-616,65
-617,65
-618,65
-619,65
-620,65
-621,65
-622,65
-623,65
-624,65
-625,65
-626,65
-627,13
-628,13
-629,13
-630,13
-631,11
-632,11
-633,11
-634,11
-635,11
-636,11
-637,11
-638,11
-639,11
-640,11
-641,11
-642,11
-643,11
-644,11
-645,11
-646,98
-647,96
-648,46
-649,44
-650,46
-651,46
-652,46
-653,46
-654,28
-655,26
-656,26
-657,26
-658,26
-659,16
-660,16
-661,16
-662,14
-663,14
-664,14
-665,14
-667,36
-668,36
-669,34
-670,34
-671,34
-672,34
-673,34
-674,34
-675,34
-676,14
-677,14
-678,14
-679,12
-680,92
-681,14
-682,14
-683,14
-684,14
-685,14
-686,12
-687,12
-688,12
-689,12
-690,12
-691,09
-692,09
-693,09
-694,07
-695,07
-696,07
-697,07
-698,07
-699,07
+602,75
+603,75
+604,75
+605,75
+606,75
+607,75
+608,73
+609,73
+610,73
+611,73
+612,73
+613,73
+614,73
+615,73
+616,73
+617,73
+618,73
+619,73
+620,73
+621,73
+622,73
+623,73
+624,73
+625,73
+626,73
+627,19
+628,19
+629,19
+630,19
+631,19
+632,19
+633,19
+634,19
+635,19
+636,19
+637,19
+638,17
+639,17
+640,17
+641,17
+642,17
+643,17
+644,17
+645,17
+646,08
+647,06
+648,50
+649,48
+650,52
+651,52
+652,52
+653,52
+654,32
+655,30
+656,30
+657,30
+658,30
+659,18
+660,18
+661,18
+662,18
+663,18
+664,18
+665,16
+667,40
+668,40
+669,40
+670,40
+671,40
+672,40
+673,40
+674,40
+675,38
+676,18
+677,16
+678,16
+679,16
+680,08
+681,18
+682,18
+683,18
+684,18
+685,16
+686,16
+687,16
+688,16
+689,16
+690,16
+691,12
+692,10
+693,10
+694,10
+695,10
+696,10
+697,10
+698,10
+699,10
 700,18
 701,18
 702,18
@@ -1292,31 +1292,33 @@ __DATA__
 726,18
 727,10
 728,14
-729,12
-730,10
-731,10
-732,10
-733,10
-750,09
-751,09
-752,03
-753,01
-756,05
-757,05
-758,05
-759,05
-760,05
-761,05
-762,05
-763,03
-764,84
-765,84
-766,66
-767,66
-768,66
-769,66
-770,66
-771,66
-772,64
+729,16
+730,16
+731,16
+732,16
+733,14
+750,12
+751,12
+752,05
+753,03
+754,03
+755,03
+756,09
+757,09
+758,09
+759,07
+760,07
+761,07
+762,07
+763,07
+764,02
+765,02
+766,80
+767,80
+768,78
+769,78
+770,78
+771,78
+772,78
 900,70-80 ## Individual Taxpayer Identification Number
 900,93-93 ## Adoption Taxpayer Identification Number
